﻿using System;
using System.Collections.Generic;
using Jypeli;
using Jypeli.Assets;
using Jypeli.Controls;
using Jypeli.Effects;
using Jypeli.Widgets;

public class Peli : PhysicsGame
{
	const double nopeus = 200;
	const double hyppyNopeus = 1000;
	const int RUUDUN_KOKO = 40;

	PlatformCharacter pelaaja1;

	Image pelaajanKuva = LoadImage("norsu");
	Image tahtiKuva = LoadImage("tahti");

	SoundEffect maaliAani = LoadSoundEffect("maali");

	public override void Begin()
	{
		Gravity = new Vector(0, -1000);

		luoKentta();
		lisaaNappaimet();

		Camera.Follow(pelaaja1);
		Camera.ZoomFactor = 1.2;
		Camera.StayInLevel = true;
	}

	void luoKentta()
	{
		TileMap kentta = TileMap.FromFile("kentta1.txt");
        kentta.SetTileMethod('#', lisaaTaso);
        kentta.SetTileMethod('*', lisaaTahti);
        kentta.SetTileMethod('N', lisaaPelaaja);
		kentta.Execute(RUUDUN_KOKO, RUUDUN_KOKO);
		Level.CreateBorders();
		Level.Background.CreateGradient(Color.White, Color.SkyBlue);
	}

	void lisaaTaso(Vector paikka, double leveys, double korkeus)
	{
		PhysicsObject taso = PhysicsObject.CreateStaticObject(leveys, korkeus);
        taso.Position = paikka;
		taso.Color = Color.Green;
        Add(taso);
	}

    void lisaaTahti(Vector paikka, double leveys, double korkeus)
	{
		PhysicsObject tahti = PhysicsObject.CreateStaticObject(leveys, korkeus);
		tahti.IgnoresCollisionResponse = true;
        tahti.Position = paikka;
		tahti.Image = tahtiKuva;
		tahti.Tag = "tahti";
        Add(tahti);
	}

    void lisaaPelaaja(Vector paikka, double leveys, double korkeus)
	{
		pelaaja1 = new PlatformCharacter(leveys, korkeus);
        pelaaja1.Position = paikka;
		pelaaja1.Mass = 4.0;
		pelaaja1.Image = pelaajanKuva;
		AddCollisionHandler(pelaaja1, kasittelePelaajanTormays);
        Add(pelaaja1);
	}

	void lisaaNappaimet()
	{
		Keyboard.Listen(Key.F1, ButtonState.Pressed, ShowControlHelp, "Näytä ohjeet");
		Keyboard.Listen(Key.Escape, ButtonState.Pressed, Exit, "Poistu pelistä");

		Keyboard.Listen(Key.Left, ButtonState.Down, liikuta, "Liikkuu vasemmalle", pelaaja1, -nopeus);
		Keyboard.Listen(Key.Right, ButtonState.Down, liikuta, "Liikkuu vasemmalle", pelaaja1, nopeus);
		Keyboard.Listen(Key.Up, ButtonState.Pressed, hyppaa, "Pelaaja hyppää", pelaaja1, hyppyNopeus);

		ControllerOne.Listen(Button.Back, ButtonState.Pressed, Exit, "Poistu pelistä");

		ControllerOne.Listen(Button.DPadLeft, ButtonState.Down, liikuta, "Pelaaja liikkuu vasemmalle", pelaaja1, -nopeus);
		ControllerOne.Listen(Button.DPadRight, ButtonState.Down, liikuta, "Pelaaja liikkuu oikealle", pelaaja1, nopeus);
		ControllerOne.Listen(Button.A, ButtonState.Pressed, hyppaa, "Pelaaja hyppää", pelaaja1, hyppyNopeus);
	}

	void liikuta(PlatformCharacter hahmo, double nopeus)
	{
		hahmo.Walk(nopeus);
	}

	void hyppaa(PlatformCharacter hahmo, double nopeus)
	{
		hahmo.Jump(nopeus);
	}

	void kasittelePelaajanTormays(PhysicsObject hahmo, PhysicsObject kohde)
	{
		if (kohde.Tag.ToString() == "tahti")
		{
			maaliAani.Play();
			MessageDisplay.Add("Keräsit tähden!");
			kohde.Destroy();
		}
	}
}
